Project Authors
===============

## Project technical lead:
* [Tonaxis](https://github.com/Tonaxis) - Developer - (France)

## Special thanks to
* [Romain Quéré](https://github.com/romainqre) for his support